==> jc-1.4.0.tar.gz: soot/jimple/toolkits/typing/integer/StronglyConnectedComponents.h <==
// class soot.jimple.toolkits.typing.integer.StronglyConnectedComponents

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d8e6007b213b718d soot_jimple_toolkits_typing_integer_StronglyConnectedComponents

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents_H_
#define _JC_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object;

typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct {
	jboolean	DEBUG;
};
extern _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$dfsg__5fvisit$a5d7a858fa06424c(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *);
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$dfsgt__5fvisit$172c6a0c0d08a403(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method_info$dfsg__5fvisit$a5d7a858fa06424c;
extern _jc_method _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method_info$dfsgt__5fvisit$172c6a0c0d08a403;

// Static methods
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$merge$757ea1443ddffead(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods {
	void	(*dfsg__5fvisit$a5d7a858fa06424c)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *);
	void	(*dfsgt__5fvisit$172c6a0c0d08a403)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods	soot_jimple_toolkits_typing_integer_StronglyConnectedComponents;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs {
	struct _jc_object	*variables;
	struct _jc_object	*black;
	struct _jc_java_util_LinkedList$object	*finished;
	struct _jc_java_util_LinkedList$object	*forest;
	struct _jc_java_util_LinkedList$object	*current__5ftree;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs {
    _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs	soot_jimple_toolkits_typing_integer_StronglyConnectedComponents;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs	soot_jimple_toolkits_typing_integer_StronglyConnectedComponents;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object {
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_integer_StronglyConnectedComponents, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/typing/integer/StronglyConnectedComponents.h <==
// class soot.jimple.toolkits.typing.integer.StronglyConnectedComponents

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d8e6007b213b718d soot_jimple_toolkits_typing_integer_StronglyConnectedComponents

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents_H_
#define _JC_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object;

typedef struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct {
	jboolean	DEBUG;
};
extern _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$fields_struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$dfsg__5fvisit$a5d7a858fa06424c(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$dfsgt__5fvisit$172c6a0c0d08a403(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method_info$dfsg__5fvisit$a5d7a858fa06424c;
extern _jc_method _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method_info$dfsgt__5fvisit$172c6a0c0d08a403;

// Static methods
extern void _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$method$merge$757ea1443ddffead(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods {
	void	(*dfsg__5fvisit$a5d7a858fa06424c)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *) _JC_JCNI_ATTR;
	void	(*dfsgt__5fvisit$172c6a0c0d08a403)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object *, struct _jc_soot_jimple_toolkits_typing_integer_TypeVariable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vmethods	soot_jimple_toolkits_typing_integer_StronglyConnectedComponents;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs {
	struct _jc_object	*variables;
	struct _jc_object	*black;
	struct _jc_java_util_LinkedList$object	*finished;
	struct _jc_java_util_LinkedList$object	*forest;
	struct _jc_java_util_LinkedList$object	*current__5ftree;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs {
    _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_refs	soot_jimple_toolkits_typing_integer_StronglyConnectedComponents;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$sub_nonrefs	soot_jimple_toolkits_typing_integer_StronglyConnectedComponents;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$object {
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$vtype _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_integer_StronglyConnectedComponents, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_integer_StronglyConnectedComponents_H_ */
